@@ -3,8 +3,9 @@ import json
 import os
 
 
-def dynamodb_list_table(region):
-    client = boto3.client('dynamodb', region_name=region)
+def dynamodb_list_table(region,AWS_ACCESS_KEY,AWS_SECRET_KEY):
+    client = boto3.client('dynamodb', region_name=region,
+    aws_access_key_id=AWS_ACCESS_KEY,aws_secret_access_key=AWS_SECRET_KEY)
     try:
         script_dir = os.path.dirname('.')
         response = client.list_tables()
