@@ -29,6 +29,6 @@ def sfn_prepare_node(region, account_id, cytoscape_node_data):
                     "name": sfn['name'],
                     "CreationDate" : sfn['creationDate'],
                     "tag": sfn_tag,
-                    "cost_for_month": "0.65 USD",
+                    "cost_for_month": 0.65
                 }
             })
